<?php
/*
	* functions.php
*/

/**
 * Flush rewrite rules for custom post type archive on single activation
 *
 * @since    0.0.1
 */
function pm_content_auditor_install() {
	global $wpdb;
	
	/*
		* Creates a directory for CSV Exports Container
	*/
	$dir_path = WP_CONTENT_DIR."/pm-content-auditor-exports";
	wp_mkdir_p($dir_path);
	$file = fopen($dir_path.'/index.php', 'w');
	fclose($file);
	
	
	$table_name = $wpdb->prefix . 'pm_content_auditor';

	$sql_push = "CREATE TABLE {$table_name} (
		id mediumint(9) NOT NULL AUTO_INCREMENT,
		filename varchar(200) NOT NULL,
		total mediumint(9) NOT NULL,
		time datetime DEFAULT '0000-00-00 00:00:00' NOT NULL,
		UNIQUE KEY id (id)
	);";
	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql_push );
	
	flush_rewrite_rules();
}

function pm_content_auditor_deactivate() {

}
if( !function_exists('pm_ppp') ) {
	function pm_ppp($var) {
		print '<pre>';
		if(is_array($var)) {
			print_r($var);	
		} else {
			print $var;
		}
		
		print '</pre>';
	}
}


/*
	* pm_content_auditor_post_types
	* Return an array with all public Content-types
*/

function pm_content_auditor_post_types(){
	$args = array(
	   'public'   => true,
	   'show_ui' => true
	);

	$output = 'names'; // names or objects, note names is the default

	$post_types = get_post_types( $args, $output ); 
	unset($post_types['attachment']);
	
	return $post_types;
}

function pm_content_auditor_post_types_html() {
	$output = "";
	$post_types = pm_content_auditor_post_types();
	//get_site_url
	
	$output .= "<select id='content_auditor_post_types' name='post_type' class='form-control'>";
	foreach($post_types as $k => $v):
	$output .= "<option value='{$v}'>{$v}</option>";
	endforeach;
	$output .= "</select>";
	
	return $output;
}

/*
	* pm_content_auditor_settings_fields
	* Fields for Settings
*/
function pm_content_auditor_setting_fields(){
	$fields = array(
	'settings' => array(
		'name' => __( 'Settings Page', 'pm-content-auditor' ),
		'general_description' => __( 'Change settings here.', 'pm-content-auditor' ),
		'fields' => array(
			'file_name' => array(
				'name' => 'file_name',
				'description' => __( 'Enter filename that will be used when exporting csv.', 'pm-content-auditor' ),
				'field' => 'input',
				'type' => 'text',
				'label' => __( 'Export Filename', 'pm-content-auditor' ),
				'default' => 'content-auditor-export',
				'limit' => '50',
				'repeatable' => false,
				'show_add' => false,
				'required' => true
			),
			'delimeter' => array(
				'name' => 'delimeter',
				'description' => __( 'Enter Delimeter that will be used for csv.', 'pm-content-auditor' ),
				'field' => 'input',
				'type' => 'text',
				'label' => __( 'CSV Delimeter', 'pm-content-auditor' ),
				'default' => ',',
				'limit' => '1',
				'repeatable' => false,
				'show_add' => false,
				'required' => true
			),
			'query_limit' => array(
				'name' => 'query_limit',
				'description' => __( 'Enter loop query limit. (A higher number will use more server load but will finish faster))', 'pm-content-auditor' ),
				'field' => 'input',
				'type' => 'text',
				'label' => __( 'Query Limit', 'pm-content-auditor' ),
				'default' => '50',
				'limit' => '3',
				'repeatable' => false,
				'show_add' => false,
				'required' => true
			)
		)
	),
	);
	
	return $fields;
}

/*
	* pm_pmover_setting_fields
	* Fields for Settings
*/
function pm_content_auditor_set_field($attr,$social,$opt){
	$output = '';
	$values = pm_content_auditor_setting_fields();
	if($attr == 'name') {
		$output = PM_CONTENT_AUDITOR_SETTINGS_OPTION . "[{$social}]" . "[{$opt}]";
	} elseif($attr == 'id') {
		$output = PM_CONTENT_AUDITOR_SETTINGS_OPTION . "_{$social}" . "_{$opt}";
	} else {
		$output = $values[$social]['fields'][$opt][$attr];
	}
	return $output;
}

/*
	Get Settings URL
*/

function pm_content_auditor_settings_url() {
	$url = admin_url('admin.php?page=pm_content_auditor_settings');
	return $url;
}

/**
	* WP Admin Ajax Processing
*/

add_action( 'wp_ajax_pm_content_auditor_ajax_process', 'pm_content_auditor_ajax_process_callback' );

function pm_content_auditor_ajax_process_callback() {
	$options = get_option(PM_CONTENT_AUDITOR_SETTINGS_OPTION, array());
	$postData = $_POST['formObject'];
	$paged = $_POST['paged'];
	$current_time = $_POST['time'];
	$export_file_name = $options['settings']['file_name'].'_'.$current_time.'.csv';
	$delimeter = $options['settings']['delimeter'];
	$query_limit = $options['settings']['query_limit'];
	$primary_fields = array_filter((!is_array($postData["primary_fields"]) ? array($postData["primary_fields"]) : $postData["primary_fields"]));
	$social_fields = array_filter((!is_array($postData["social_fields"]) ? array($postData["social_fields"]) : $postData["social_fields"]));
	$yoast_seo = array_filter((!is_array($postData["yoast_seo"]) ? array($postData["yoast_seo"]) : $postData["yoast_seo"]));
	$custom_fields = array_filter((!is_array($postData["custom_fields"]) ? array($postData["custom_fields"]) : $postData["custom_fields"]));
	$csv_headers = array_merge(array('pid'),$primary_fields, $social_fields, $yoast_seo, $custom_fields);
	/**
	* Start Query	
	*/
	$post_type = trim($postData['post_type']);
	$post_status = array_filter((!is_array($postData["post_status"]) ? array($postData["post_status"]) : $postData["post_status"]));
	
	// WP_Query arguments
	$args = array (
		'post_type'              => array( $post_type ),
		'cache_results' => false,
		'post_status'            => $post_status,
		'nopaging'               => false,
		'paged'                  => $paged,
		'posts_per_page'         => $query_limit,
	);
	if( $postData['post_range'] == 'date_range' ) {
		$args['date_query'] = array(
			array(
				'before'     => $postData['end_date'],
				'after'     => $postData['start_date'],
				'inclusive' => true,
			)
		);
	}
	// The Query
	$ca_query = new WP_Query( $args );
	
	//Set Data Array
	$data = array();
	$data['paged'] = $paged + 1;
	$data['total_posts'] = $ca_query->found_posts;
	$data['paged_posts'] = $ca_query->post_count;
	$data['paged_total'] = $ca_query->max_num_pages;
	$data['fileDownload'] = WP_CONTENT_URL."/pm-content-auditor-exports/".$export_file_name;
	$data['time_start'] = $current_time;
	$data['last'] = ($paged == $data['paged_total'] ? true : false);
	
	$export_dir_path = WP_CONTENT_DIR."/pm-content-auditor-exports/";
	$export_file_name_path = $export_dir_path.$export_file_name;
	
	// The Loop
	ob_start();
	$fh = (file_exists($export_file_name_path) ? @fopen($export_file_name_path, 'a') : @fopen($export_file_name_path, 'w') );
	if ( $ca_query->have_posts() ) {
		$loop_key = 1;
		while ( $ca_query->have_posts() ) {
			$ca_query->the_post();	
			$pid = $ca_query->post->ID;
			$p = $ca_query->post;
			//Social Shares
			if( !empty($social_fields) ) {
				$social_shares = pm_content_auditor_count_social(get_permalink($pid));
				$social_shares = json_decode($social_shares);
			}
			
			
			$csv_array = array();
			$csv_array['pid'] = $pid;
			if(in_array('title', $csv_headers)) {
				$csv_array['title'] = (in_array('title', $csv_headers) ? get_the_title($pid) : '' );
			}
			if(in_array('published_date', $csv_headers)) {
				$csv_array['published_date'] = (in_array('published_date', $csv_headers) ? $p->post_date : '' );
			}
			if(in_array('post_status',$csv_headers) ) {
				$csv_array['post_status'] = (in_array('post_status',$csv_headers) ? $p->post_status : '' );
			}
			if(in_array('post_author',$csv_headers)) {
				$csv_array['post_author'] = (in_array('post_author',$csv_headers) ? $p->post_author : '' );
			}

			if( $p->post_type == 'post'){
				
				if(in_array('category', $csv_headers)) {
					$categories_obj = get_categories($pid);
					$categories = array();
					if( is_array($categories_obj) ) {
						foreach($categories_obj  as $cat) {
							$categories[] = $cat->term_id;
						}
					}
					$csv_array['category'] = (in_array('category', $csv_headers) ? implode('|', $categories) : '' );
				}
				
				if(in_array('tags', $csv_headers)) {
					$tags_obj = get_the_tags($pid);
					$tags = array();
					if(is_array($tags_obj)) {
						foreach($tags_obj  as $t) {
							$tags[] = $t->slug;
						}
					}
					$csv_array['tags'] = (in_array('tags', $csv_headers) ? implode('|', $tags) : '' );
				}

			}
			if(in_array('featured_image', $csv_headers)) {
				$csv_array['featured_image'] = (in_array('featured_image', $csv_headers) ? get_post_thumbnail_id($pid) : '' );
			}			
			if(in_array('facebook_shares', $csv_headers)) {
				$csv_array['facebook_shares'] = (in_array('facebook_shares', $csv_headers) ? $social_shares->facebookshares : 0 );
			}
			if(in_array('googleplus', $csv_headers)) {
				$csv_array['googleplus'] = (in_array('googleplus', $csv_headers) ? $social_shares->googleplusones : 0 );
			}
			
			if( !empty($yoast_seo) ) {			
				foreach($yoast_seo as $ys) {
					$csv_array[$ys] = (is_array(get_post_meta($pid, $ys, true)) ? serialize(get_post_meta($pid, $ys, true)) : get_post_meta($pid, $ys, true));
				}
			}
			
			if( !empty($custom_fields) ) {
				foreach($custom_fields as $cf) {
					$csv_array[$cf] = (is_array(get_post_meta($pid, $cf, true)) ? serialize(get_post_meta($pid, $cf, true)) : get_post_meta($pid, $cf, true));
				}
			}
			
			if($paged == 1 && $loop_key == 1) {
				fputcsv($fh, $csv_headers,$delimeter);
			}
			fputcsv($fh, $csv_array,$delimeter);
			unset($csv_array);
			$loop_key ++;
		}
	} else {	
		// no posts found
	}
	// Restore original Post Data
	wp_reset_postdata();
	@fclose($fh);
	ob_get_clean();
	
	/*
		* Insert Log when All Export is Finished
	*/
	if( $data['last'] ){
		pm_content_auditor_add_log($data);
	}
	
	
	print json_encode($data);
	die(); // this is required to return a proper result
}


/*
	* Count Social Shares of Selected Post
	* pm_content_auditor_count_social
*/

function pm_content_auditor_count_social($link) {
	include_once('libs/social-count/social-count.php');
	$args = array('url' => $link);
	$args['facebook'] = true;
	$args['google'] = true;
	$count = null;
	/*
	if( isset($options['pmac_addsocial']) && is_array($options['pmac_addsocial']) ){
		$facebook = (in_array('facebook', $options['pmac_addsocial']) ? $args['facebook'] = true : false);
		$pinterest = (in_array('pinterest', $options['pmac_addsocial']) ? $args['pinterest'] = true : false);
		$linkedin = (in_array('linkedin', $options['pmac_addsocial']) ? $args['linkedin'] = true : false);
		$google = (in_array('google', $options['pmac_addsocial']) ? $args['google'] = true : false);
		
		// Example Usage passing in Array of netowrks we want countsa for...
	}
	*/
	$socialCounts = new socialNetworkShareCount($args);
	$count =  $socialCounts->getShareCounts();
	return $count;
	
}

/*
	* pm_content_auditor_add_log
*/

function pm_content_auditor_add_log($data){
	global $wpdb;
	$table_name = $wpdb->prefix . 'pm_content_auditor';
	$args = array(
		'filename'	=>	$data['fileDownload'],
		'total'	=> $data['total_posts']
	);
	
	$defaults = array(
		'filename'	=>	'',
		'total'	=> ''
	);

	$args = wp_parse_args( $args, $defaults );
	$add = $wpdb->query(
		$wpdb->prepare(
			"INSERT INTO {$table_name} SET
				`filename`    = '%s',
				`total`    = '%s',
				`time`    = NOW()
			;",
			$args['filename'],
			$args['total']
		)
	);
}

/*
	* pm_content_auditor_log_objects
*/

function pm_content_auditor_log_objects() {
	global $wpdb;
	$table_name = $wpdb->prefix . 'pm_content_auditor';
	
	$results = $wpdb->get_results( "SELECT * FROM {$table_name}", OBJECT );
	
	return $results;
}


